Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(193)

Unified Diff: third_party/WebKit/Source/core/streams/ReadableStreamOperations.h

Issue 1902673003: Reflect recent spec changes to V8 Extra ReadableStream impl (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fixed build Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/streams/ReadableStreamOperations.h
diff --git a/third_party/WebKit/Source/core/streams/ReadableStreamOperations.h b/third_party/WebKit/Source/core/streams/ReadableStreamOperations.h
index 0051bee22f405d52e0b5dd1c919fe6f2c57410a7..049c10e68553407e18083199285301109e791887 100644
--- a/third_party/WebKit/Source/core/streams/ReadableStreamOperations.h
+++ b/third_party/WebKit/Source/core/streams/ReadableStreamOperations.h
@@ -30,7 +30,7 @@ public:
// createBuiltInCountQueuingStrategy
static ScriptValue createCountQueuingStrategy(ScriptState*, size_t highWaterMark);
- // AcquireReadableStreamReader
+ // AcquireReadableStreamDefaultReader
// This function assumes |isReadableStream(stream)|.
// Returns an empty value and throws an error via the ExceptionState when
// errored.
@@ -59,12 +59,12 @@ public:
// This function assumes |isReadableStream(stream)|.
static bool isErrored(ScriptState*, ScriptValue stream);
- // IsReadableStreamReader
- static bool isReadableStreamReader(ScriptState*, ScriptValue);
+ // IsReadableStreamDefaultReader
+ static bool isReadableStreamDefaultReader(ScriptState*, ScriptValue);
- // ReadFromReadableStreamReader
- // This function assumes |isReadableStreamReader(reader)|.
- static ScriptPromise read(ScriptState*, ScriptValue reader);
+ // ReadableStreamDefaultReaderRead
+ // This function assumes |isReadableStreamDefaultReader(reader)|.
+ static ScriptPromise defaultReaderRead(ScriptState*, ScriptValue reader);
};
} // namespace blink

Powered by Google App Engine
This is Rietveld 408576698